@@ -133,6 +133,12 @@ def All():
 
 
 def main():
+    if len(sys.argv) >= 2:
+        if sys.argv[1] in ['-h', '-H', '--help']:
+            print('24p 1 2 3 4 # for query')
+            print('24p # for play game')
+            return
+
     v = list(map(lambda x: int(x), sys.argv[1:]))
     n = len(v)
 
